#ifndef NT2_INCLUDE_CONSTANTS_SIGNMASK_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_SIGNMASK_HPP_INCLUDED

#include <nt2/constant/include/constants/signmask.hpp>

#endif
